import { Type } from '@angular/core';
import { ManagerInterface } from './Manager.interface';
import { ConfigurationInterface } from '../Configuration';
import { SwoWorker } from './Worker';
import { EntityInterface } from '../Entity/EntityInterface.interface';
import { ConnectorInterface } from '../Adapters/ConnectorInterface';
import { SQLite } from '@ionic-native/sqlite';
/**
 * @dynamic
 */
export declare class Manager implements ManagerInterface {
    private sqlite;
    static connector: ConnectorInterface;
    static worker: SwoWorker;
    protected configuration: ConfigurationInterface;
    protected currentAdapter: string;
    constructor(sqlite: SQLite);
    /**
     * Retrieve the connector
     */
    getConnector(): ConnectorInterface;
    /**
     * Set the connector
     * @param connector
     */
    setConnector(connector: ConnectorInterface): void;
    /**
     * Sets and returns the connection handler following the user configuration
     */
    getConnection(): Promise<any>;
    /**
     * Get connection handler by guessing adapter
     * @param sqlite
     * @param configuration
     */
    private autoDetectConnection();
    /**
     * Resets the connection and the worker
     */
    reset(): void;
    /**
     * Set configuration
     * @param configuration
     */
    setConfiguration(configuration: ConfigurationInterface): ManagerInterface;
    /**
     * Get configuration
     */
    getConfiguration(): ConfigurationInterface;
    /**
     * Returns the current adapter
     */
    getAdapter(): string;
    /**
     * Add an obect to the queue for save
     * @param entityInstance
     */
    persist(entityInstance: EntityInterface): ManagerInterface;
    /**
     * Add an obect to the queue for update
     * @param entityInstance
     */
    merge(entityInstance: EntityInterface): ManagerInterface;
    /**
     * Add an obect to the queue for remove
     * @param entityInstance
     */
    remove(entityInstance: EntityInterface): ManagerInterface;
    /**
     * Add to the queue a request to remove a whole table
     * @param constructorObject
     */
    removeAll(constructorObject: Type<any>): ManagerInterface;
    /**
     * Asynchrone flush. Executes all the operations saved into the queue
     * @param entityInstance EntityInterface
     */
    flush(entityInstance?: EntityInterface): Promise<{}>;
}
