import { Type } from '@angular/core';
import { Manager } from '../Manager/Manager.service';
import { SQLFactory } from '../Schema/SQL.service';
import { UpdateOption, DeleteOption, SelectOption, InsertOption } from '../Schema/SQLQueriesInterfaces';
import { EntityInterface } from '../Entity/EntityInterface.interface';
import { RepositoryInterface } from '../Repository/RepositoryInterface.interface';
/**
 *  @dynamic
 */
export declare class EntityRepository implements RepositoryInterface {
    manager: Manager;
    static repositories: {};
    protected sqlTransactionObject: any;
    /**
     * A token to store the class managed by this repository
     * @property classToken
     */
    classToken: Type<any>;
    /**
     * Connection object to handle queries
     * @property connection
     */
    private connection;
    /**
     * Sql service
     * @property sqlService
     */
    protected sqlService: SQLFactory;
    /**
     * Repository loaded from the current adapter
     * @property internalRepository
     */
    private internalRepository;
    constructor(manager: Manager);
    private getInternalRepository();
    getManager(): Manager;
    getSqlService(): SQLFactory;
    getRepositories(): any;
    getSchema(): Array<any>;
    getJointures(): Array<any>;
    getClassToken(): Type<any>;
    /**
     * Convert a database array to an entity instance
     * @param array
     */
    mapArrayToObject(array: Array<any>): EntityInterface;
    select(options: SelectOption): Promise<EntityInterface[]>;
    insert(object: EntityInterface, options?: InsertOption): Promise<EntityInterface>;
    update(arg: EntityInterface, options?: UpdateOption): Promise<boolean>;
    delete(entity?: EntityInterface, options?: DeleteOption): Promise<boolean>;
    /**
     * Find by id
     * @param id
     */
    find(id: number): Promise<EntityInterface | null>;
    /**
     * Find by criteria
     * @param options
     */
    findBy(options: any): Promise<EntityInterface[]>;
    /**
     * Find one result following the search criteria
     * @param options
     */
    findOneBy(options: any): Promise<EntityInterface | null>;
    /**
     * Find all the results in this table
     */
    findAll(): Promise<EntityInterface[]>;
}
