import { EntityInterface } from '../Entity/EntityInterface.interface';
import { DeleteOption, UpdateOption, SelectOption } from './SQLQueriesInterfaces';
/**
 *  @dynamic
 */
export declare class SQLFactory {
    /**
     * @property lastQuery The last query done on the server
     */
    private lastQuery;
    getLastQuery(): string;
    /**
   * The function creates a SQL query that creates a table
   * @param options : contains many parameters required for the table creation
   * {
   * fields : object which keys are column names and values are column types. Ex : { name : TEXT, age : INTEGER }
   * schema : ... { name: 'firstname', type: 'TEXT'}
   * erase : boolean to tell if we override the previous table
   * tableName : table name == entity class name
   * }
   */
    getCreateTableSql(options: any): string;
    getSelectSql(classname: string, options: SelectOption): string;
    getInsertSql(classname: string, object: EntityInterface): string;
    getUpdateSql(classname: string, options: UpdateOption, object?: EntityInterface): string;
    getDeleteSql(classname: string, entity?: EntityInterface, options?: DeleteOption): string;
    /**
     * Build the 'WHERE' clause into the SQL request
     * @param conditions
     */
    buildSqlWhereClause(conditions?: Array<string>): string;
}
